create table number_four (
    x int,
    y int,
    z int,
    t int
);

comment on table number_four is 'this is table four';
comment on column number_four.x is 'this is the x coordinate';
comment on column number_four.y is 'this is the y coordinate';
comment on column number_four.t is 'this is time!';


